@@ -1,5 +1,5 @@
 package Class::props ;
-$VERSION = 1.52 ;
+$VERSION = 1.53 ;
 
 
 ; use 5.006_001
@@ -138,9 +138,9 @@ __END__
 
 Class::props - Pragma to implement lvalue accessors with options
 
-=head1 VERSION 1.52
+=head1 VERSION 1.53
 
-Included in OOTools 1.52 distribution. The distribution includes:
+Included in OOTools 1.53 distribution. The distribution includes:
 
 =over
 
@@ -385,7 +385,7 @@ More information at http://perl.4pro.net/?Class::props.
 
 =head1 AUTHOR and COPYRIGHT
 
- 2004 by Domizio Demichelis <dd@4pro.net>.
+ 2004 by Domizio Demichelis.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as perl itself.
 
